@@ -10,12 +10,18 @@ Oak::Web::HTML::H4 - H4 HTML Tag
 
 =head1 HIERARCHY
 
-  Oak::Object
-  Oak::Persistent
-  Oak::Component
-  Oak::Web::Visual
-  Oak::Web::HTML::H
-  Oak::Web::HTML::H4
+L<Oak::Object|Oak::Object>
+
+L<Oak::Persistent|Oak::Persistent>
+
+L<Oak::Component|Oak::Component>
+
+L<Oak::Web::Visual|Oak::Web::Visual>
+
+L<Oak::Web::HTML::H|Oak::Web::HTML::H>
+
+L<Oak::Web::HTML::H4|Oak::Web::HTML::H4>
+
 
 =head1 PROPERTIES
 
